@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -134,27 +134,27 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
 
     mRenameCategoriesList.clear();
     // Load *.renamecategories file in QStandardPaths::ConfigLocation for kde apps.
-    QStringList dirs = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString &dir, dirs) {
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory);
+    for (const QString &dir : dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.renamecategories"));
-        Q_FOREACH (const QString &file, fileNames) {
+        for (const QString &file : fileNames) {
             mRenameCategoriesList.append(KDebugSettingsUtil::readRenameCategories(dir + file));
         }
     }
     //TODO add load rename file from external kde apps.
-    dirs = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QStringLiteral("qdebug.categories/"), QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString &dir, dirs) {
+    const QStringList dirs2 = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QStringLiteral("qdebug.categories/"), QStandardPaths::LocateDirectory);
+    for (const QString &dir : dirs2) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.renamecategories"));
-        Q_FOREACH (const QString &file, fileNames) {
+        for (const QString &file : fileNames) {
             mRenameCategoriesList.append(KDebugSettingsUtil::readRenameCategories(dir + file));
         }
     }
 
     // Load *.categories file in QStandardPaths::ConfigLocation for kde apps.
-    dirs = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString &dir, dirs) {
+    const QStringList dirs3 = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory);
+    for (const QString &dir : dirs3) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.categories"));
-        Q_FOREACH (const QString &file, fileNames) {
+        for (const QString &file : fileNames) {
             if (file != QStringLiteral("kde.categories")) {
                 KDebugSettingsUtil::readLoggingCategories(dir + file, mCategoriesList, true);
             }
@@ -162,10 +162,10 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
     }
 
     // Load *.categories files. in qdebug.categories for external kde apps.
-    dirs = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QStringLiteral("qdebug.categories/"), QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString &dir, dirs) {
+    const QStringList dirs4 = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QStringLiteral("qdebug.categories/"), QStandardPaths::LocateDirectory);
+    for (const QString &dir : dirs4) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.categories"));
-        Q_FOREACH (const QString &file, fileNames) {
+        for (const QString &file : fileNames) {
             KDebugSettingsUtil::readLoggingCategories(dir + QLatin1Char('/') + file, mCategoriesList, true);
         }
     }
@@ -211,10 +211,10 @@ bool KDebugSettingsDialog::saveRules(const QString &path)
     const LoggingCategory::List lstCustom = mCustomSettingsPage->rules();
     QTextStream out(&qtlogging);
     out << QLatin1String("[Rules]\n");
-    Q_FOREACH (LoggingCategory cat, lstKde) {
+    for (LoggingCategory cat : lstKde) {
         out << cat.createRule() + QLatin1Char('\n');
     }
-    Q_FOREACH (LoggingCategory cat, lstCustom) {
+    for (LoggingCategory cat : lstCustom) {
         out << cat.createCustomRule() + QLatin1Char('\n');
     }
     return true;
@@ -250,7 +250,7 @@ void KDebugSettingsDialog::slotInsertCategories()
     if (!path.isEmpty()) {
         const KdeLoggingCategory::List insertCategoriesList = KDebugSettingsUtil::readLoggingCategoriesForInserting(path, mCategoriesList);
         LoggingCategory::List newCategories;
-        Q_FOREACH (const KdeLoggingCategory &cat, insertCategoriesList) {
+        for (const KdeLoggingCategory &cat : qAsConst(insertCategoriesList)) {
             LoggingCategory loggingCat;
             loggingCat.description = cat.description;
             loggingCat.logName = cat.logName;
